@@ -7,6 +7,8 @@ use rand::random;
 use reqwest::Client;
 use reqwest::{Method, StatusCode};
 use serde::{Deserialize, Serialize};
+#[allow(unused_imports)]
+use simple_log::{debug, info};
 use std::{fs::File, io::Write, path::PathBuf, str, time::SystemTime};
 use tiny_http::{Response, Server};
 
@@ -118,6 +120,8 @@ impl MALClient {
     ///Listens for the OAuth2 callback from MAL on `callback_url`, which is the redirect_uri
     ///registered when obtaining the API token from MAL. Only HTTP URIs are supported right now.
     ///
+    ///# NOTE
+    ///
     ///For now only applications with a single registered URI are supported, having more than one
     ///seems to cause issues with the MAL api itself
     ///
@@ -160,6 +164,7 @@ impl MALClient {
                 continue;
             }
             let res_raw = i.url();
+            debug!("raw response: {}", res_raw);
             code = res_raw
                 .split_once('=')
                 .unwrap()
@@ -211,7 +216,7 @@ impl MALClient {
             }
             Ok(())
         } else {
-            Err(MALError::new("Unable to get tokends", "None", text))
+            Err(MALError::new("Unable to get tokens", "None", text))
         }
     }
 
@@ -267,7 +272,7 @@ impl MALClient {
             Err(_) => Err(match serde_json::from_str::<MALError>(res) {
                 Ok(o) => o,
                 Err(e) => MALError::new(
-                    "Unable to parse response",
+                    "unable to parse response",
                     &format!("{}", e),
                     res.to_string(),
                 ),
@@ -528,7 +533,6 @@ impl MALClient {
             .await;
         match res {
             Ok(r) => {
-                println!("{:?}", r.status());
                 if r.status() == StatusCode::NOT_FOUND {
                     Err(MALError::new(
                         &format!("Anime {} not found", id),
@@ -626,15 +630,15 @@ impl MALClient {
     }
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Deserialize)]
 pub(crate) struct TokenResponse {
-    pub token_type: String,
+    pub _token_type: String,
     pub expires_in: u32,
     pub access_token: String,
     pub refresh_token: String,
 }
 
-#[derive(Serialize, Deserialize, Debug)]
+#[derive(Serialize, Deserialize)]
 pub(crate) struct Tokens {
     pub access_token: String,
     pub refresh_token: String,
